compute_env_hash: Compute environment image hash

View source: R/utils.R

compute_env_hashR Documentation

Compute environment image hash

Description

Computes the hash used to tag environment Docker images, combining the renv.lock file contents with the starburst package version. This ensures new images are built when either the R package environment or the starburst worker script changes.

Usage

compute_env_hash(lock_file)

Arguments

lock_file

Path to renv.lock file

Value

MD5 hash string


starburst documentation built on March 19, 2026, 5:08 p.m.