| compute_env_hash | R Documentation |
Computes the hash used to tag environment Docker images, combining the renv.lock file contents with the starburst package version. This ensures new images are built when either the R package environment or the starburst worker script changes.
compute_env_hash(lock_file)
lock_file |
Path to renv.lock file |
MD5 hash string
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.